@@ -11,9 +11,11 @@ from pyhilo.device.switch import Switch  # noqa
 
 class Devices:
     def __init__(self, api: API):
+        """Initialize."""
         self._api = api
         self.devices: list[HiloDevice] = []
         self.location_id: int = 0
+        self.location_hilo_id: str = ""
 
     @property
     def all(self) -> list[HiloDevice]:
@@ -36,6 +38,9 @@ class Devices:
         ]
 
     def parse_values_received(self, values: list[dict[str, Any]]) -> list[HiloDevice]:
+        """Places value received in a dict while removing null attributes,
+        this returns values to be mapped to devices.
+        """
         readings = []
         for val in values:
             val["device_attribute"] = self._api.dev_atts(
@@ -47,9 +52,13 @@ class Devices:
     def _map_readings_to_devices(
         self, readings: list[DeviceReading]
     ) -> list[HiloDevice]:
+        """Uses the dict from parse_values_received to map the values to devices."""
         updated_devices = []
         for reading in readings:
-            if device := self.find_device(reading.device_id):
+            device_identifier = reading.device_id
+            if device_identifier == 0:
+                device_identifier = reading.hilo_id
+            if device := self.find_device(device_identifier):
                 device.update_readings(reading)
                 LOG.debug(f"{device} Received {reading}")
                 if device not in updated_devices:
@@ -60,10 +69,16 @@ class Devices:
                 )
         return updated_devices
 
-    def find_device(self, id: int) -> HiloDevice:
-        return next((d for d in self.devices if d.id == id), None)  # type: ignore
+    def find_device(self, device_identifier: int | str) -> HiloDevice:
+        """Makes sure the devices received have an identifier, this means some need to be hardcoded
+        like the unknown power meter.
+        """
+        if isinstance(device_identifier, int):
+            return next((d for d in self.devices if d.id == device_identifier), None)
+        return next((d for d in self.devices if d.hilo_id == device_identifier), None)
 
     def generate_device(self, device: dict) -> HiloDevice:
+        """Generate all devices from the list received."""
         device["location_id"] = self.location_id
         if dev := self.find_device(device["id"]):
             dev.update(**device)
@@ -92,13 +107,24 @@ class Devices:
                 # Don't do anything with unpaired device for now.
                 # self.devices.remove(device)
 
-    async def update_gateway(self) -> None:
-        gateway = await self._api.get_gateway(self.location_id)
-        LOG.debug(f"Generating device (gateway) {gateway}")
-        self.generate_device(gateway)
+    async def update_devicelist_from_signalr(
+        self, values: list[dict[str, Any]]
+    ) -> list[HiloDevice]:
+        # ic-dev21 not sure if this is dead code?
+        new_devices = []
+        for raw_device in values:
+            LOG.debug(f"Generating device {raw_device}")
+            dev = self.generate_device(raw_device)
+            if dev not in self.devices:
+                self.devices.append(dev)
+                new_devices.append(dev)
+
+        return new_devices
 
     async def async_init(self) -> None:
         """Initialize the Hilo "manager" class."""
         LOG.info("Initialising after websocket is connected")
-        self.location_id = await self._api.get_location_id()
+        location_ids = await self._api.get_location_ids()
+        self.location_id = location_ids[0]
+        self.location_hilo_id = location_ids[1]
         await self.update()
